@@ -15,6 +15,7 @@ import json
 class BaseCoco(BaseLabelme):
 
     def __init__(self, *args, **kwargs):
+        self.parameter = None
         self.coco_dataset = {"categories": [], "images": [], "annotations": [], "info": "", "licenses": []}
         self.anns = dict()  # anns[annId]={}
         self.cats = dict()  # cats[catId] = {}
@@ -56,7 +57,7 @@ class BaseCoco(BaseLabelme):
     #     img_id = self.imgNameToId.get(image_name, None)
     #     return img_id is not None
 
-    def add_image(self, file_name: str, width: int, height: int, img_id: int = None):
+    def add_image(self, file_name: str, width: int, height: int, img_id: int = None, md5_value: str = None, ):
         """
         追加图片描述属性，返回图片image_id
         :param file_name:
@@ -64,6 +65,11 @@ class BaseCoco(BaseLabelme):
         :param height:
         :param img_id:
         :return:
+        @param img_id:
+        @param height:
+        @param width:
+        @param file_name:
+        @param md5_value:
         """
         # if self.has_image(file_name):
         #     print(f"{file_name}图片已存在")
@@ -75,7 +81,8 @@ class BaseCoco(BaseLabelme):
             "id": img_id,
             "width": width,
             "height": height,
-            "file_name": file_name
+            "file_name": file_name,
+            "md5_value": md5_value,
         }
         self.coco_dataset["images"].append(image)
         self.imgs[img_id] = image
@@ -165,7 +172,7 @@ class BaseCoco(BaseLabelme):
         self.cats[category_id] = cat
         self.coco_dataset["categories"].append(cat)
 
-    def self2coco(self):
+    def self2coco(self, parameter):
         """
         通过继承和实现基类中的方法来方便地扩展和实现更多的功能
         约定规则，
@@ -179,6 +186,7 @@ class BaseCoco(BaseLabelme):
         9、目前多边形标注的还有关键点标注，统一放到segmentation中存储
         10、矩形框的标注直接转coco,一个shape一个注释
         """
+        self.parameter = parameter
         print('实现BaseLabelme基类中的，labelme转coco方法')
         for dataset in tqdm(self.datasets):
             self.output_dir = dataset.get('output_dir')
@@ -193,7 +201,7 @@ class BaseCoco(BaseLabelme):
                 one_img_ann_list = self.labelme_shapes2coco_ann(dataset)
                 # 2、添加coco类别
                 # print(f'coco转换数据处理开始')
-                for ann in one_img_ann_list:  # 一张图像的多个标注及组合标注在这里进行迭代，迭代前必须组合完成
+                for ann in one_img_ann_list:  # 一张图像的多个标注及组合标注在这里进行迭代，迭代前必须组合完成。列表中存放字典元素
                     category_id = 0
                     # 如果标注的标签不存在，就category_id加1
                     if ann['label'] not in self.categories_name:
@@ -235,7 +243,7 @@ class BaseCoco(BaseLabelme):
             segmentation = list()
             rebuild_polygon_point_shape = {}  # 存储shape重构为coco标注属性字典变量
             # 注意：处理的数据中如果存在打组又不打组的情况，转出来的coco数据集会出错
-            if isinstance(structure_shape_key, int):  # 处理打组的数据
+            if isinstance(structure_shape_key, int) and self.parameter.coco_to_bbox is not True:  # 处理打组的数据
                 self.group_id_mark = True  # 打组就把条件变成真
                 # if len(structure_shape_value) == 5:  # 长度等于5，关键点和矩形框分组，转换为一个coco注释
                 # 通过返回的shape_type来判断属于那种组合，是否需要追加到one_img_ann_list
@@ -251,12 +259,20 @@ class BaseCoco(BaseLabelme):
                 else:
                     print("分组的labelme转换为coco数据存在未按照约定规则进行处理，暂时跳过转换！当前约定规则为（point，polygon，plate，有分组）（polygon，plate，有分组）")
                     continue
-            if structure_shape_key is None:  # 处理不打组的数据，即分组键为None，只有矩形框未分组的可以转coco注释
+            if structure_shape_key is None and self.parameter.coco_to_bbox is not True:  # 处理不打组的数据，即分组键为None，只有矩形框未分组的可以转coco注释
                 # 一张图像如果标注都没有打组，就会直接把所有标注shape进行迭代
                 self.shape_processing(structure_shape_value, dataset, one_img_ann_list, point_list, rebuild_polygon_point_shape)
                 convert_segmentation = sum(segmentation, point_list)  # 把列表中存储的多个元组元素，合并成一个列表且保持原有排列顺序
                 rebuild_polygon_point_shape.update({'segmentation': convert_segmentation})  # 新增关键点列表，按照左上、右上、右下、左下的顺序排序
                 one_img_ann_list.append(rebuild_polygon_point_shape)  # 把标注shape追加到转coco时的迭代列表集合中
+            if self.parameter.coco_to_bbox:  # 处理多边形转coco为bbox，矩形框转coco为bbox
+                for shape in structure_shape_value:
+                    if shape.setdefault('shape_type') == 'polygon' and self.parameter.coco_to_bbox is True:
+                        polygon = self.polygon_shape_bbox(shape, dataset)
+                        one_img_ann_list.extend(polygon)
+                    if shape.setdefault('shape_type') == 'rectangle':  # 目前存在组合：1、多边形和矩形框组合。2、点和矩形框组合
+                        rectangle = self.rectangle_shape_bbox(shape)
+                        one_img_ann_list.extend(rectangle)
         return one_img_ann_list
 
     def image_handle(self, dataset):
@@ -269,10 +285,10 @@ class BaseCoco(BaseLabelme):
         # image = Image.open(dataset.get('full_path'))  # 通过PIL模块获取图像宽高
         if dataset.get('http_url'):  # 如果http_url有值，表示转换为带http路径的coco图像路径
             file_name = os.path.join(dataset.get('http_url'), make_up_img_dir).replace("\\", "/")
-            self.result_addImage_id = self.add_image(file_name, dataset.get('image_width'), dataset.get('image_height'), None)
+            self.result_addImage_id = self.add_image(file_name, dataset.get('image_width'), dataset.get('image_height'), None, dataset.get('md5_value'))
         else:  # 转换为相对路径的coco图像路径
             file_name = os.path.join('./', make_up_img_dir).replace("\\", "/")  # 组合图像文件名称相对路径
-            self.result_addImage_id = self.add_image(file_name, dataset.get('image_width'), dataset.get('image_height'), None)
+            self.result_addImage_id = self.add_image(file_name, dataset.get('image_width'), dataset.get('image_height'), None, dataset.get('md5_value'))
 
     @staticmethod
     def rebuild_labelme_info(labelme_info):
@@ -321,7 +337,7 @@ class BaseCoco(BaseLabelme):
         """
         shape_type = list()
         for shape in structure_shape_value:
-            if shape.setdefault('shape_type') == 'polygon':
+            if shape.setdefault('shape_type') == 'polygon' and self.parameter.coco_to_bbox is not True:
                 res = self.polygon_shape(shape, dataset, one_img_ann_list, rebuild_polygon_point_shape)
                 shape_type.append(shape.setdefault('shape_type'))
                 shape_type.append(res)
@@ -336,7 +352,7 @@ class BaseCoco(BaseLabelme):
 
     def polygon_shape(self, shape, dataset, one_img_ann_list, rebuild_polygon_point_shape):
         """
-        处理标注形状为多边形的shape
+        处理标注形状为多边形的shape，1、多边形转segmentation列表，2、多边形转矩形框
         :param shape: 标注属性字典
         :param dataset:一张图像属性封装字典集合
         :param one_img_ann_list:
@@ -481,3 +497,49 @@ class BaseCoco(BaseLabelme):
     #         # clamp_y2 = np.clip(y2, 0, dataset.get('image_height'))
     #         # dataset.update({'output_dir': dataset.get('out_of_bounds_path')})
     #         return True
+    def polygon_shape_bbox(self, shape, dataset):
+        """
+        把多边形转为矩形框
+        @param shape:
+        @param dataset:
+        """
+        one_img_ann_list = list()
+        file_path = dataset.get('full_path')
+        rebuild_polygon_point_shape = {}  # 存储shape重构为coco标注属性字典变量
+        if len(shape['points']) == 4:
+            polygon_points = np.array(shape['points'])
+            point_min, point_max = polygon_points.min(axis=0), polygon_points.max(axis=0)
+            # 求出坐标点的极大值和极小值后，无需管先后顺序，直接填入shape['points']中,变成矩形框左上角坐标、右下角坐标
+            bbox = [[point_min[0], point_min[1]], [point_max[0], point_max[1]]]  # 把多边形标注转成矩形框
+            if self.rectangle_cross_the_border(bbox, dataset, True):  # 如果函数返回为True，表示标注形状已经超出图像边界
+                print(f'标注形状超出图像边界。人工核对后，选择程序进行矫正错误{file_path}')
+                self.error_dataset_handle(dataset)
+            else:
+                try:
+                    # 内存里更新shape标注属性
+                    rebuild_polygon_point_shape.update({'bbox': bbox})  # 更新多边形点的坐标为矩形框坐标
+                    rebuild_polygon_point_shape.update({'label': shape['label']})
+                    if 'text' in shape:  # 判断 'text' 键是否存在
+                        if shape['text'] is not None:  # 判断 'text' 值是否存在
+                            rebuild_polygon_point_shape.update({'score': shape['text']})  # 如果阈值存在，就把阈值添加进去
+                    one_img_ann_list.append(rebuild_polygon_point_shape)
+                except Exception as e:
+                    print(e)
+                    file_path = dataset.get('full_path')
+                    print(f'多边形排序出错{file_path}')
+        else:
+            print(f'车牌多边形标注不为4个点,已经存储到自定义默认错误数据集目录，修改完成后覆盖真实数据集，并重新转换')
+            dataset.update({'output_dir': dataset.get('error_path')})
+        return one_img_ann_list
+
+    @staticmethod
+    def rectangle_shape_bbox(shape):
+        one_img_ann_list = list()
+        rebuild_rectangle_shape = {}  # 存储shape重构为coco标注属性字典变量
+        rebuild_rectangle_shape.update({'bbox': shape['points']})  # 更新多边形点的坐标为矩形框坐标
+        rebuild_rectangle_shape.update({'label': shape['label']})
+        if 'text' in shape:  # 判断 'text' 键是否存在
+            if shape['text'] is not None:  # 判断 'text' 值是否存在
+                rebuild_rectangle_shape.update({'score': shape['text']})  # 如果阈值存在，就把阈值添加进去
+        one_img_ann_list.append(rebuild_rectangle_shape)
+        return one_img_ann_list
