@@ -27,7 +27,8 @@ def parser_args():
     parser.add_argument('--only-select-shapes', action="store_true", help="默认False，是否只筛选标注有框的数据。是为True，否为False")
     parser.add_argument('--shapes-attribute', type=str, help="筛选属性，包含label（类别）、shape_type（类别形状）、flags（类别属性）")
     parser.add_argument('--filter-flags', type=ast.literal_eval, help="类别属性筛选，输入类别属性字典列表。比如person类下有，手、脚、头")
-    parser.add_argument('--file-formats', default=['.jpg', '.jpeg', '.png', '.JPEG', '.JPG', '.PNG'], type=str, help="文件格式")
+    parser.add_argument('--file-formats', default=['.jpg', '.jpeg', '.png', '.JPEG', '.JPG', '.PNG', '.webp'], type=str,
+                        help="文件格式,其中,'.bmp','.gif','.tif',格式图像不做处理")
     parser.add_argument('--filter-combin', action="store_true", help="是否组合筛选，是为True，否为False")
     parser.add_argument('--extract-portion', type=int, help='按照指定份数平均抽取，比如400张图像，抽取10分，每份40张')
     parser.add_argument('--extract-text', type=ast.literal_eval, help='按照text字段的文本内容抽取')
@@ -53,6 +54,7 @@ def parser_args():
     parser.add_argument('--leak-check', action="store_true", help="默认False，填写参数代表为true，用于筛选漏检出数据。是为True，否为False")
     parser.add_argument('--error-check', action="store_true", help="默认False，填写参数代表为true，用于筛选误检出数据。是为True，否为False")
     parser.add_argument('--right-check', action="store_true", help="默认False，填写参数代表为true，用于筛选正确检出数据。是为True，否为False")
+    parser.add_argument('--coco-to-bbox', action="store_true", help="默认False，填写参数代表为true，用于判断多边形转矩形框。是为True，否为False")
     parser.add_argument('--background', action="store_true", help="默认False，填写参数代表为true，用于把系统输出的json转换为labelme对应的json。是为True，否为False")
     parser.add_argument('--is-PCA', action="store_true",
                         help="默认False，填写参数代表为true，用于直方图降维条件判断。是为True，但会造成信息丢失，否为False，信息更准确")
@@ -63,7 +65,9 @@ def parser_args():
     parser.add_argument('--helmet-true', type=str, help="分类目录规则,helmet")
     parser.add_argument('--helmet-false', type=str, help="分类目录规则，no_select")
     parser.add_argument('--mv5-value', type=str, help="分类目录规则，no_select")
-
+    parser.add_argument('--flags-value', type=ast.literal_eval, help="填写flags的字典值")
+    parser.add_argument('--image-check', action="store_true",
+                        help="默认False，填写参数代表为true即开启检查功能并移除图像，用于检查图像格式、通道、完整性及其它问题。是为True，否为False")
     args = parser.parse_args()
 
     if args.function == 'filter_positive':  # 筛选正样本
@@ -141,6 +145,14 @@ def parser_args():
         return args
     elif args.function == 'soft_deletion':  # 把json数据删除，属于软删除，等同于只拷贝一份图像，原始数据保留
         return args
+    elif args.function == 'crop':  # 把目标检测标注的矩形框，截取图像
+        return args
+    elif args.function == 'check_format':  # 检查图像是否存在，格式不对、通道不对、内容完整性不对等问题
+        return args
+    elif args.function == 'move':  # 移动文件，临时功能
+        return args
+    elif args.function == 'modify_flags':  # 修改flags字典值
+        return args
     else:
         assert not args.function, '传入的操作功能参数不对:{}'.format(args.function)
 
@@ -149,7 +161,7 @@ def main():
     # async def main():
     args = parser_args()
     # print(args)
-    # 把字符串转换成，列表内存储字典元素
+    # 把字符串中，转义字符转换成，列表内存储字典元素.
     input_datasets_list = ast.literal_eval(args.input_datasets.replace('\\', '/'))
     if args.sync:  # 同步读写数据处理
         data_info = LabelmeLoad(args, input_datasets_list)  # 初始化输入参数
@@ -161,8 +173,8 @@ def main():
             print(time.time() - async_time)
         if args.function == 'pinyin':
             data_info.hanzi_to_pinyin()  # 对中文路径转拼音后，重新输出
-        # if args.function == 'rename':  # 对中文的文件名称，转英文
-        #     data_info.get_english_name()
+        if args.function == 'check_format':  # 检查图像格式
+            data_info.check_images_format()
     else:  # 异步读写数据处理，存在少部分同步写数据处理
         async_time = time.time()
         data_info = LabelmeLoad(args, input_datasets_list)  # 初始化输入参数
@@ -185,15 +197,17 @@ def main():
             dataset.intercept_coordinates()
         elif args.function == 'duplicate':  # 对labelme数据集进行去重，重复的图片就删除
             dataset.duplicate_images()
-        # print(args.min_pixel)
-        # dataset.crop_objs(args.min_pixel)
+        elif args.function == 'crop':
+            dataset.crop_objs(args)  # 目标检测矩形框，截取图像
         elif args.function == 'convert':  # 转换功能，包含labelme转coco，coco转labelme
             if args.output_format == 'labelme':  # coco转labelme
-                pass
+                # 由于dataset_info封装的数据集，无法快速索引，在coco转labelme的时候，从新封装该对象，无需传入labelme基类中
+                coco_to_labelme = CocoToLabelme(input_datasets_list)
+                coco_to_labelme.coco2labelme()
                 # dataset.save_labelme(args.output_dir, None)  # 如果输出路径为空，就直接修改输入目录下的json文件，不为空则重新拷贝图像文件与重写json文件
             elif args.output_format == 'coco':  # labelme转coco
                 coco = BaseCoco(dataset_info)
-                coco.self2coco()
+                coco.self2coco(args)
             elif args.output_format == 'voc':  # voc转labelme
                 voc = BaseVoc(dataset_info, input_datasets_list[0].get('input_xml_dir'))
                 voc.voc2labelme()
@@ -278,6 +292,12 @@ def main():
             dataset.soft_deletion_json(args)
         elif args.function == 'rename_file_name':  # 自定义格式把文件重命名
             dataset.rename_file_name(args)
+        # elif args.function == 'image_check':  # 检查图像问题，包含格式、完整性、通道及其它问题
+        #     dataset.image_check(args)
+        elif args.function == 'move':  # 自定义格式把文件重命名
+            dataset.move_file(args)
+        elif args.function == 'modify_flags':  # 修改falgs值
+            dataset.modify_flags(args)
 
 
 if __name__ == '__main__':
